@@ -1232,6 +1232,7 @@ class TemplateDeployer:
         self.stack.set_stack_status("UPDATE_IN_PROGRESS")
         # apply changes
         self.apply_changes(self.stack, new_stack, stack_name=self.stack.stack_name, action="UPDATE")
+        self.stack.set_time_attribute("LastUpdatedTime")
 
     def delete_stack(self):
         if not self.stack:
@@ -1249,6 +1250,7 @@ class TemplateDeployer:
                 self.stack.set_resource_status(resource_id, "DELETE_COMPLETE")
         # update status
         self.stack.set_stack_status("DELETE_COMPLETE")
+        self.stack.set_time_attribute("DeletionTime")
 
     # ----------------------------
     # DEPENDENCY RESOLUTION UTILS
@@ -1615,6 +1617,13 @@ class TemplateDeployer:
                         if not self.all_resource_dependencies_satisfied(resource):
                             j += 1
                             continue
+                    elif action == "Remove":
+                        should_remove = self.prepare_should_deploy_change(
+                            resource_id, change, stack, new_resources
+                        )
+                        if not should_remove:
+                            del changes[j]
+                            continue
                     self.apply_change(change, stack=stack)
                     changes_done.append(change)
                     del changes[j]
@@ -1668,6 +1677,13 @@ class TemplateDeployer:
                     resource.get("Type"),
                 )
                 return False
+        elif action == "Remove":
+            should_remove = self.is_deployable_resource(resource)
+            if not should_remove:
+                LOG.debug(
+                    f"Action 'remove' not yet implemented for CF resource type {resource.get('Type')}"
+                )
+            return should_remove
         return True
 
     def apply_change(self, change, stack):
